@@ -22,7 +22,7 @@ def differ():
 
 
 #@click.pass_context
-#@differ.command()
+@differ.command()
 #@click.option("cassette_path", type=click.Path(exists=True))
 @click.argument("cassette_path", type=str)
 @click.option("--host", help="HOST.", required=False, type=str, default='')
